<?php
/**
 * Namespace Teknisa\Logic\SIT
 *
 * PHP version 5
 *
 * @category Php
 * @package  Teknisa\Logic\SIT
 * @author   andreteixeira <andre.teixeira@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
namespace Teknisa\Logic\SIT;

use Geral\Entities\Nutriente;
use Geral\Entities\Organizacao;
use Geral\Entities\Paramgeral;
use Geral\Entities\Produto as ProdutoEntity;
use Geral\Repositories\Produto;
use Geral\Util\AcumuladorDeMensagens;
use Geral\Util\Ambiente;
use Geral\Util\DateUtil;
use Geral\Util\TratamentoDeMensagens;
use Planejamento\Entities\Grupnutr;
use Planejamento\Entities\Nutrprod;
use Setforms2\Shared\ORM\DateTime;
use Setforms2\Shared\Registry;
use Teknisa\Entities\Remprodnutr as RemprodnutrEntity;
use Teknisa\Entities\SitLogprod;
use Teknisa\Repositories\SitLogprod as SitLogprodRepository;
use Teknisa\Repositories\Remprodnutr;

/**
 * Class IntBrowser
 * VISÃO CLIENTE
 *
 * PHP version 5
 *
 * @category Php
 * @package  Teknisa\Logic\SIT
 * @author   andreteixeira <andre.teixeira@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
class IntBrowser
{

    //Constante que define o máximo de produtos a serem enviados por Remessa.
    const MAX_PRODENV = 1000;

    //Constante que define o máximo de produtos a serem recebidos por Remessa.
    const MAX_PRODRET = 200;

    /**
     * Realiza o envio dos produtos do Cliente para o Servidor da Teknisa,
     * para que os nutrientes possam ser cadastrados através do processo de
     * Integração de Nutrientes.
     *
     * @return null
     */
    public function enviaProdutosIntegracao()
    {
        $insereMsg = true;
        $nrorg     = Ambiente::getNrorg();

        //Valida se o Cliente usa a Integração.
        $idintegra = '';
        $paramgeral = Paramgeral::getObjectByWhere(
            "NRORG = ? AND CDPARGERAL = '0001'",
            array($nrorg)
        );
        if ($paramgeral instanceof Paramgeral) {
            $idintegra = $paramgeral->getIdintegra();
        }
        if ((empty($idintegra) === true) || ($idintegra == 'N')) {
            try {
                tk_abort(
                    tk_get_message_by_name(
                        'msg_ger07600_parametrizarNutrientes'
                    )
                );
            } catch (\Exception $e) {
                tk_message($e->getMessage(), 'error');
                return;
            }
        }

        //Busca o NRORGINT
        $nrorgint   = null;
        $paramgeral = Paramgeral::getObjectByWhere(
            "NRORG = ? AND CDPARGERAL = '0001'", array($nrorg)
        );
        if ($paramgeral instanceof Paramgeral) {
            $nrorgint = $paramgeral->getNrorgintegra();
        }

        //Verifica se os Parâmetros de Nutriente foram definidos.
        if (empty($nrorgint)) {
            try {
                tk_abort(
                    tk_get_message_by_name(
                        'msg_ger07600_parametrizarNutrientes'
                    )
                );
            } catch (\Exception $e) {
                tk_message($e->getMessage(), 'error');
                return;
            }
        }

        //Busca as Remessas de Envio que estão pendentes.
        $arr_remessas = RemprodnutrEntity::getObjectsByWhere(
            "NRORG = ? AND IDTPREMESSA = ? AND IDSITREMESSA = ?",
            array($nrorg, 'E', 'N'),
            "NRREMESSA"
        );

        $produtos = 0;

        //Busca os Produtos de cada Remessa e faz uma nova tentativa de Requisição
        if (is_array($arr_remessas)) {
            foreach ($arr_remessas as $remessa) {
                if ($remessa instanceof RemprodnutrEntity) {
                    $arr_produtos = Produto::sqlProdutosRemessaPendente(
                        $nrorg, $remessa->getNrremessa()
                    );
                }

                if (empty($arr_produtos) === false) {
                    $produtos += count($arr_produtos);
                    $arr_arr_produtos = array_chunk($arr_produtos, self::MAX_PRODENV);

                    $insereMsg = self::insereRemessaProdutos(
                        $arr_arr_produtos, true, $remessa->getNrremessa()
                    );

                    tk_reload_data_with_filter(
                        'tab_ger07600_000', 'win_ger07600_000'
                    );
                }
            }
        }

        //Busca os produtos a serem enviados.
        $arr_produtos = Produto::sqlProdutosIntegracao($nrorg);

        //$insereMsg = true;

        if (empty($arr_produtos) === false) {
            $produtos += count($arr_produtos);

            //Divide os produtos em grupos de 1000.
            $arr_arr_produtos = array_chunk($arr_produtos, self::MAX_PRODENV);

            //Gera a Remessa de Produtos
            $insereMsg = self::insereRemessaProdutos($arr_arr_produtos);

            tk_reload_data_with_filter(
                'tab_ger07600_000', 'win_ger07600_000'
            );
        }

        if ($insereMsg) {
            $msg = tk_get_message_by_name(
                'msg_ger07600_ProdutosEnviados', array($produtos)
            );
            if (!AcumuladorDeMensagens::getInstance()->mensagemExiste($msg)) {
                AcumuladorDeMensagens::getInstance()->addMensagem($msg);
            }
        }

        //Mostra as mensagens acumuladas.
        TratamentoDeMensagens::exibeMensagensAcumuladasAgrupadas();

        tk_reload_data_with_filter(
            'tab_ger07600_000', 'win_ger07600_000'
        );
    }

    /**
     * Função que insere Remessas e Produtos no banco.
     * Gera um JSON que contém o Número da Remessa (NRREMESSA),
     * o Número da Organização de Integração do Cliente (NRORGINT),
     * a quantidade de produtos enviados (QTPRODENV) e a lista de
     * produtos que serão integrados (PRODUTOS).
     *
     * @param Array  $arr_arr_produtos Array de Array de Produtos
     * @param Bool   $reenvio          Caracteriza Reenvio da Remessa
     * @param String $nrremessa        Número da Remessa para o Reenvio
     *
     * @return null
     * @throws \Exception
     */
    public static function insereRemessaProdutos (
        $arr_arr_produtos, $reenvio = false, $nrremessa = null
    ) {
        $retorno = true;
        $nrorg      = Ambiente::getNrorg();
        $nrorgint   = null;
        $paramgeral = Paramgeral::getObjectByWhere(
            "NRORG = ? AND CDPARGERAL = '0001'", array($nrorg)
        );
        if ($paramgeral instanceof Paramgeral) {
            $nrorgint = $paramgeral->getNrorgintegra();
        }

        //Verifica se os Parâmetros de Nutriente foram definidos.
        if (empty($nrorgint) === true) {
            try {
                tk_abort(
                    tk_get_message_by_name(
                        'msg_ger07600_parametrizarNutrientes'
                    )
                );
            } catch (\Exception $e) {
                tk_warning($e->getMessage());
                return false;
            }
        }

        $dataAtual  = self::geraDataAtual();
        $cdoperador = Ambiente::getCdOperador();

        $conn = Registry::getEntityManager();
        try {
            foreach ($arr_arr_produtos as $arr_produtos) {
                $json = array();
                $conn->beginTransaction();

                if (!$reenvio) {
                    //Para cada um dos grupos de 1000 produtos, uma remessa é gerada.
                    $nrremessa = RemprodnutrEntity::novaRemessa(
                        $nrorg, $dataAtual, $cdoperador, 'E'
                    );

                    $conn->flush();
                }


                //Monta o JSON
                $json['NRREMESSA'] = $nrremessa;
                $json['NRORGINT']  = $nrorgint;
                $json['QTPRODENV'] = count($arr_produtos);
                $json['PRODUTOS']  = array();

                foreach ($arr_produtos as $produto) {
                    //Cada um dos 1000 produtos é inserido na SitLogprod com
                    //o número da remessa gerada.
                    if ($produto instanceof ProdutoEntity) {
                        $cdproduto  = $produto->getCdproduto();
                        $observacao = $produto->getDsobsnutr();
                    } else {
                        $cdproduto  = $produto['CDPRODUTO'];
                        $observacao = $produto['OBSERVACAO'];
                    }

                    ProdutoEntity::atualizaIdalteranutr(
                        $nrorg, $cdproduto, 'N'
                    );

                    $prod = SitLogprod::getObjectByWhere(
                        "NRREMESSA = ? AND CDPRODUTO = ?",
                        array($nrremessa, $cdproduto)
                    );

                    if (!$prod instanceof SitLogprod) {
                        SitLogprod::insereProduto(
                            $nrremessa, $cdproduto, $observacao,
                            $nrorg, $dataAtual, $cdoperador
                        );
                    }

                    //Insere o produto no JSON
                    $json['PRODUTOS'][] = $produto;
                }

                $conn->flush();
                $conn->commit();

                //Converte o array para o formato JSON
                $json = json_encode($json);

                //Para cada Remessa gerada, envia uma Requisição.
                $retorno = self::trataRetorno(
                    self::enviaRequisicao('envProduto', $json),
                    $nrorg, $nrremessa
                );
            }
            return $retorno;
        } catch (\Exception $e) {
            $conn->rollback();
            throw $e;
        }
    }

    /**
     * Envia a requisição para a realização da Integração.
     * Recebe um JSON que será passado como parâmetro do POST.
     * A requisição é feita utilizando cURL.
     *
     * @param String $rota Rota
     * @param String $json JSON
     *
     * @return null
     */
    public static function enviaRequisicao($rota, $json = null)
    {
        //$url = "http://localhost:9090/v_220/products/projects/sit/public/serviceBrowser/index.php/".$rota;
        $nrorg      = Ambiente::getNrorg();
        $paramgeral = Paramgeral::getObjectByWhere(
            "NRORG = ? AND CDPARGERAL = '0001'", array($nrorg)
        );
        if ($paramgeral instanceof Paramgeral) {
            $url = $paramgeral->getDsendeintegra();
        }

        if (empty($url) === true) {
            try {
                tk_abort(
                    tk_get_message_by_name(
                        'msg_ger07600_parametrizarNutrientes'
                    )
                );
            } catch (\Exception $e) {
                tk_warning($e->getMessage());
                return false;
            }
        }

        $ch  = curl_init();

        $curlConfig = array(
            CURLOPT_URL            => $url.'/'.$rota,
            CURLOPT_RETURNTRANSFER => true
        );

        if ($json !== null) {
            $curlConfig[CURLOPT_POST]       = true;
            $curlConfig[CURLOPT_POSTFIELDS] = array('json' => $json);
        }

        curl_setopt_array($ch, $curlConfig);
        $response = curl_exec($ch);

        if ($response == false) {
            $response = curl_error($ch);
        }

        curl_close($ch);

        return $response;
    }

    /**
     * Trata o retorno do WebService.
     * Se resp é um JSON, o processo foi bem sucedido.
     *
     * @param String $resp      String JSON ou Mensagem de Erro
     * @param String $nrorg     Organização
     * @param String $nrremessa Número da Remessa
     *
     * @return null
     * @throws \Exception
     */
    public function trataRetorno ($resp, $nrorg, $nrremessa)
    {
        if ((empty($resp) === false) && ($resp != 'null')) {

            //Busca a Remessa a ser atualizada.
            $remprodnutr = RemprodnutrEntity::getObjectByWhere(
                "NRORG = ? AND NRREMESSA = ?",
                array($nrorg, $nrremessa)
            );

            if ($remprodnutr instanceof RemprodnutrEntity) {
                //Se encontrou a remessa, realiza as atualizações.
                $conn = Registry::getEntityManager();
                try {

                    //Verifica se a mensagem de erro foi retornada dentro de um JSON
                    $resp2 = json_decode($resp);
                    if (is_array($resp2)) {
                        if (!array_key_exists(1, $resp2)) {
                            $resp = $resp2[0];
                        }
                    }

                    $conn->beginTransaction();
                    if (json_decode($resp) != false) {
                        //Se a string retornada for o JSON, sucesso.
                        RemprodnutrEntity::atualizaSituacaoRemessa(
                            $remprodnutr, 'S'
                        );

                        //Limpa a mensagem de erro da remessa.
                        RemprodnutrEntity::atualizaMensErroRemessa(
                            $remprodnutr, null
                        );

                        $retorno = true;
                    } else {
                        //Se a String retornada for uma mensagem de erro, falha.
                        if (empty($resp) === false) {
                            $resp = self::trataMensagensExcecoes($resp);

                            RemprodnutrEntity::atualizaMensErroRemessa(
                                $remprodnutr, $resp
                            );

                            if (!AcumuladorDeMensagens::getInstance()->mensagemExiste(
                                $resp
                            )) {
                                AcumuladorDeMensagens::getInstance()->addMensagem(
                                    $resp
                                );
                            }
                        }

                        $retorno = false;
                    }

                    $conn->flush();
                    $conn->commit();

                    return $retorno;
                } catch (\Exception $e) {
                    $conn->rollback();
                    throw $e;
                }
            }
        }
    }

    /**
     * Gerencia o Recebimento de Nutrientes e Produtos por parte do Cliente.
     * A função é chamada quando o Cliente clica em "Receber Produtos".
     *
     * @return null
     */
    public static function gerenciaRecebimento()
    {
        $nrorg   = Ambiente::getNrorg();

        //Valida se o Cliente usa a Integração.
        $idintegra = '';
        $paramgeral = Paramgeral::getObjectByWhere(
            "NRORG = ? AND CDPARGERAL = '0001'",
            array($nrorg)
        );
        if ($paramgeral instanceof Paramgeral) {
            $idintegra = $paramgeral->getIdintegra();
        }
        if ((empty($idintegra) === true) || ($idintegra == 'N')) {
            try {
                tk_abort(
                    tk_get_message_by_name(
                        'msg_ger07600_parametrizarNutrientes'
                    )
                );
            } catch (\Exception $e) {
                tk_message($e->getMessage(), 'error');
                return;
            }
        }

        //Busca o NRORGINT
        $nrorgint   = null;
        $paramgeral = Paramgeral::getObjectByWhere(
            "NRORG = ? AND CDPARGERAL = '0001'", array($nrorg)
        );
        if ($paramgeral instanceof Paramgeral) {
            $nrorgint = $paramgeral->getNrorgintegra();
        }

        //Verifica se os Parâmetros de Nutriente foram definidos.
        if (empty($nrorgint)) {
            try {
                tk_abort(
                    tk_get_message_by_name(
                        'msg_ger07600_parametrizarNutrientes'
                    )
                );
            } catch (\Exception $e) {
                tk_message($e->getMessage(), 'error');
                return;
            }
        }

        //Define a Data Atual
        $dataAtual = self::geraDataAtual();

        //Busca as Remessas pendentes
        $remessasPendentes = RemprodnutrEntity::getObjectsByWhere(
            "NRORG = ? AND IDTPREMESSA = ? AND IDSITREMESSA = ?",
            array($nrorg, 'R', 'N'),
            "NRREMESSA"
        );

        $produtos = 0;
        if (is_array($remessasPendentes)) {
            foreach ($remessasPendentes as $remessa) {
                if ($remessa instanceof RemprodnutrEntity) {
                    $json               = array();
                    $json['NRORG']      = $nrorg;
                    $json['NRORGINT']   = $nrorgint;
                    $json['NRREMESSA']  = $remessa->getNrremessa();
                    $json['PENDENTE']   = '1';
                    $json['MAXPRODRET'] = self::MAX_PRODRET;
                    $json               = json_encode($json);

                    $prod = self::enviaRequisicao('recProduto', $json);
                    self::insereProdutos(json_decode($prod, true));
                    self::trataRetorno($prod, $nrorg, $remessa->getNrremessa());

                    $produtos += count(json_decode($prod, true));
                }
            }
        }

        $recNutr  = true;
        do {
            //Gera uma nova Remessa
            $nrremessa = RemprodnutrEntity::novaRemessa(
                $nrorg, $dataAtual, Ambiente::getCdOperador(), 'R'
            );

            //Gera o JSON
            $json               = array();
            $json['NRORG']      = $nrorg;
            $json['NRORGINT']   = $nrorgint;
            $json['NRREMESSA']  = $nrremessa;
            $json['PENDENTE']   = '0';
            $json['MAXPRODRET'] = self::MAX_PRODRET;
            $json               = json_encode($json);

            //Busca os Nutrientes somente uma vez.
            if ($recNutr) {
                $nutr = self::enviaRequisicao('recNutriente', $json);
                self::insereNutrientes(json_decode($nutr, true));
                $insereMsg = self::trataRetorno($nutr, $nrorg, $nrremessa);
                $recNutr = false;

                if ($insereMsg) {
                    $msg = tk_get_message_by_name(
                        'msg_ger07600_nutrientesAtualizados'
                    );
                    if (!AcumuladorDeMensagens::getInstance()->mensagemExiste($msg)) {
                        AcumuladorDeMensagens::getInstance()->addMensagem($msg);
                    }
                }
            }

            //Busca os produtos liberados
            $prod = self::enviaRequisicao('recProduto', $json);
            self::insereProdutos(json_decode($prod, true));
            $insereMsg = self::trataRetorno($prod, $nrorg, $nrremessa);

            //Se nenhum produto foi retornado, exclui a remessa.
            if (json_decode($prod, true) == false) {
                RemprodnutrEntity::excluiRemessa($nrorg, $nrremessa, 'R');
            }

            $prods = json_decode($prod, true);
            if (is_array($prods)) {
                $prods = $prods[0];
                if (!is_array($prods)) {
                    $prods = json_decode($prods, true);
                }
            }
            while (($prods != null) && (!is_array($prods))) {
                $prods = json_decode($prod, true);
            }
            $produtos += count($prods);

        } while (count($prods) == self::MAX_PRODRET);

        if ($insereMsg) {
            $msg = tk_get_message_by_name(
                'msg_ger07600_NutrprodAtualizado', array($produtos)
            );
            if (!AcumuladorDeMensagens::getInstance()->mensagemExiste($msg)) {
                AcumuladorDeMensagens::getInstance()->addMensagem($msg);
            }
        }

        //$dtinicial    = tk_get_context_vars('DTINICIAL', 'win_ger07600_000');
        //$dtfinal      = tk_get_context_vars('DTFINAL',   'win_ger07600_000');
        //$cdarvprodini = tk_get_context_vars('CDARVPRODINI', 'win_ger07600_000');
        //$cdarvprodfin = tk_get_context_vars('CDARVPRODFIN', 'win_ger07600_000');

        tk_reload_data_with_filter(
            'tab_ger07600_003', 'win_ger07600_000'
        );

        TratamentoDeMensagens::exibeMensagensAcumuladasAgrupadas();

    }

    /**
     * Insere os Grupos e os Nutrientes no Banco do Cliente.
     * Considera que as tabelas foram previamente apagadas.
     *
     * @param Array $nutrientes Array de Nutrientes e Grupos de Nutrientes
     *
     * @return null
     * @throws \Exception
     */
    public static function insereNutrientes ($nutrientes)
    {
        if (!is_array($nutrientes)) {
            $nutrientes = json_decode($nutrientes, true);
        }

        if (is_array($nutrientes)) {
            $nutrientes = $nutrientes[0];
            if (!is_array($nutrientes)) {
                $nutrientes = json_decode($nutrientes, true);
            }
        }

        if ($nutrientes !== false) {
            $conn = Registry::getEntityManager();
            try {
                $conn->beginTransaction();
                //
                if (is_array($nutrientes['GRUPNUTR'])) {
                    foreach ($nutrientes['GRUPNUTR'] as $grupnutr) {
                        $obj = Grupnutr::getObjectByWhere(
                            "NRORG = ? AND CDGRUPNUTR = ?",
                            array($grupnutr['NRORG'], $grupnutr['CDGRUPNUTR'])
                        );

                        Grupnutr::criaGrupnutr(
                            $grupnutr['NRORG'], self::geraDataAtual(),
                            Ambiente::getCdOperador(), $grupnutr['CDGRUPNUTR'],
                            $grupnutr['NMGRUPNUTR'], $obj
                        );
                    }
                    $conn->flush();
                }
                //
                if (is_array($nutrientes['NUTRIENTE'])) {
                    foreach ($nutrientes['NUTRIENTE'] as $nutriente) {
                        $obj = Nutriente::getObjectByWhere(
                            "NRORG = ? AND CDNUTRIENTE = ?",
                            array($nutriente['NRORG'], $nutriente['CDNUTRIENTE'])
                        );

                        Nutriente::novoNutriente(
                            $nutriente['NRORG'], self::geraDataAtual(),
                            $nutriente['CDNUTRIENTE'], $nutriente['NMNUTRIENTE'],
                            $nutriente['NMREDUZIDO'], $nutriente['IDTIPONUTR'],
                            $nutriente['SGUNIDADE'], $nutriente['CDGRUPNUTR'],
                            Ambiente::getCdOperador(), $nutriente['IDATIVO'],
                            $nutriente['IDCALORIAS'], $nutriente['IDNUTRRELEV'],
                            $nutriente['VRFATORNUTR'], $nutriente['IDKCAL'],
                            $nutriente['NRORDEMNUTR'], $obj
                        );
                    }
                }
                //
                $conn->flush();
                $conn->commit();
            } catch (\Exception $e) {
                $conn->rollback();
                throw $e;
            }
        }
    }

    /**
     * Insere os Produtos no Banco do Cliente
     *
     * @param String $produtos JSON Produtos
     *
     * @return null
     * @throws \Exception
     */
    public static function insereProdutos ($produtos)
    {
        if (!is_array($produtos)) {
            $produtos = json_decode($produtos, true);
        }

        if (is_array($produtos)) {
            $produtos = $produtos[0];
            if (!is_array($produtos)) {
                $produtos = json_decode($produtos, true);
            }
        }

        //Define a Data Atual
        $dataAtual  = self::geraDataAtual();

        if (is_array($produtos)) {

            $conn = Registry::getEntityManager();
            try {
                $conn->beginTransaction();

                foreach ($produtos as $produto) {

                    $nrorgint     = $produto['NRORGINT'];
                    $nrremessaori = $produto['NRREMESSAORI'];
                    $nrremessaret = $produto['NRREMESSARET'];
                    $cdproduto    = $produto['CDPRODUTOINT'];
                    $idativo      = $produto['IDATIVO'];
                    $nutrprod     = $produto['NUTRPROD'];
                    $qtpesoint    = $produto['QTPESOINT'];

                    if ($idativo == "S") {
                        foreach ($nutrprod as $nutr) {
                            //Insere os produtos no banco.
                            Nutrprod::insereNutrprod(
                                $cdproduto, $nutr['CDNUTRIENTE'],
                                $nutr['QTNUTRPROD'], $nutr['DSFONTNUTR'],
                                $nutr['NRORG'], $dataAtual,
                                Ambiente::getCdOperador()
                            );
                        }

                        //Atualiza o peso do Produto
                        ProdutoEntity::atualizaPesoProduto(
                            Ambiente::getNrorg(), $cdproduto,
                            $qtpesoint, $dataAtual
                        );
                    } else if ($idativo == "N") {
                        //Atualiza o registro de produto: IDTEMNUTRIENTE = 'N'.
                        ProdutoEntity::atualizaIdTemNutriente(
                            Ambiente::getNrorg(), $cdproduto, "N"
                        );
                    }

                    //Atualiza os campos de retorno da SIT_LOGPROD
                    SitLogprod::atualizaRetorno(
                        $nrremessaori, $cdproduto, $nrremessaret,
                        $dataAtual, $idativo
                    );
                }

                $conn->flush();
                $conn->commit();
            } catch (\Exception $e) {
                $conn->rollback();
                throw $e;
            }
        }
    }

    /**
     * Retorna um objeto DateTime sem hora.
     *
     * @return array|bool|\DateTime|DateTime|string.
     * @throws \Exception
     */
    public static function geraDataAtual()
    {
        $dataAtual  = now();
        if ($dataAtual instanceof DateTime) {
            $dataAtual = DateUtil::truncateData($dataAtual);
        } else {
            $dataAtual = explode(' ', $dataAtual);
            $dataAtual = $dataAtual[0];
            $dataAtual = DateUtil::getDataDeString($dataAtual);
        }

        return $dataAtual;
    }

    /**
     * Trata as Exceções disparadas no Servidor.
     * Busca as mensagens amigáveis para o usuário no Metadados.
     * Para tratar outras mensagens, basta adicionar um IF com a RegExp da mesagem
     * a ser tratada, e retornar a mensagem correspondente no metadados.
     *
     * @param String $mensagem Mensagem
     *
     * @return array.
     */
    public static function trataMensagensExcecoes ($mensagem)
    {
        if (preg_match('/not found/i', $mensagem) != false) {
            return tk_get_message_by_name('msg_ger07600_msgErroURLNotFound');
        }

        if (preg_match('/#10061/i', $mensagem) != false) {
            return tk_get_message_by_name('msg_ger07600_msgErro10061');
        }

        if (preg_match('/couldn\'t connect to host/i', $mensagem) != false) {
            return tk_get_message_by_name('msg_ger07600_msgErroURLNotFound');
        }

        if (preg_match('/could not resolve host/i', $mensagem) != false) {
            return tk_get_message_by_name('msg_ger07600_msgErroURLNotFound');
        }

        return $mensagem;
    }

}
