function Est11000_EntradaEstoque_Service(Est11000_EntradaEstoque_Repository) {
    var permiteEstNegat;

    var dtprocessa;
    var idctrlestq;
    var idutilalmox;
    var idutillcestq;
    var idpermestneg;

	/**
	 * Essa função tem como finalidade verificar se um dataSource existe um produto igual ao
	 * produto que está sendo inserido no momento. É retirada a ultiam posição do array pois
	 * ela é o registro que o usuário está inserindo no momento.
	 *
	 * @param data | array de itens ja inclusos na retirada
	 * @param cdarvprod | código do produto que está sendo inserido
	 * @param cdalmoxarife | código do almoxarifado do produto que está sendo inserido
	 * @param cdlocalestoq | código do localização do produto que está sendo inserido
	 * @param nrloteestq | código do lote do produto que está sendo inserido
	 * @param nrsublote | código do sublote do produto que está sendo inserido
	 */
	this.checaItensDaRetirada = function(data, cdarvprod, cdalmoxarife, cdlocalestoq, nrloteestq, nrsublote) {
		var contem = false;
		data.splice(data.length -1, 1);
		data.forEach(function(item){
			 if(item.CDARVPROD === cdarvprod) {
			 	contem = true;
			 	if(item.CDALMOXARIFE !== cdalmoxarife) {
			 		contem = false;
			 	} else if(item.CDLOCALESTOQ !== cdlocalestoq) {
			 		contem = false;
			 	} else if(item.NRLOTEESTQ !== nrloteestq) {
			 		contem = false;
			 	} else if(item.NRSUBLOTE !== nrsublote) {
			 		contem = false;
			 	}
			 }
		});
		return contem;
	};

	/**
	 * Essa função tem a finalidade de consultar o cdtipocusto.
	 *
	 * @param cdfilial | filial movimentada
	 *
	 * @return string | valor do CDTIPOCUSTO
	 */
	this.getCdtipocusto = function(cdfilial) {
		return Est11000_EntradaEstoque_Repository.getCdtipocusto(cdfilial).then(function(callback){
			return callback.dataset.paramfilial[0].CDTIPCUSTEST;
		});
	};

	/**
	 * Essa função serve para consultar os itens da requisição que foi passada.
	 *
	 * @param cdfilial | código da filial movimentada
	 * @param nrrequesto | código da requisição passada
	 *
	 */
	this.getItensOfRequisicao = function(cdfilial, nrrequesto) {
		var filter = [{
						"name": "CDFILIAL",
						"operator": "=",
						"value": cdfilial
					  },
					  {
					  	"name": "NRREQUESTO",
						"operator": "=",
						"value": nrrequesto
					  },
					  {
					  	"name": "IDSTITREQU",
						"operator": "=",
						"value": 'A'
					  }];
		return Est11000_EntradaEstoque_Repository.findItensOfRequisicao(filter).then(function(succes){
			return succes.dataset.itrequesto_itens_requisicao;
		});
	};

    /**
     *
     *
     */
    this.geraNrsequitem= function(itens) {
		var nrsequitemArray=[0];
		itens.forEach(function(item) {
		    if(item.NRSEQUITEM)
			    nrsequitemArray.push(item.NRSEQUITEM);
		});
		return ('000'+(Math.max.apply(this,nrsequitemArray)+1)).slice(-4);
	};

	/**
	 * Essa função tem como finalidade montar chamar a função do repository que retorne
	 * as parametrizações da filial que foi passada para essa função. Depois disso é
	 * chegado se essa função foi chamada no inicio da tela. Se sim seta variavéis
	 * globais com as parametrizações necessárias na tela. Se não, retorna a row pesqui-
	 * sada.
	 *
	 * @param cdfilial | codigo da filial que foi selecionada no filtro
	 * @return array | retorna o retorno da função (Nome e código da filial)
	 * @return objetc | objeto com os campos que retornaram do select das parametrizações
	 */
	this.getParamFilial = function(cdfilial, onInit) {
	    var filter = [{ "name": "CDFILIAL",
	    				"operator": "=",
	    				"value": cdfilial
	    			},{ "name": "P_CDFILIAL",
	    				"operator": "=",
	    				"value": null}];
	    return Est11000_EntradaEstoque_Repository.getParamFilial(filter).then(function(succes){
	        var parans = succes.dataset.paramfilial_paramvalidacoes[0];
			if(parans) {
	        	if(onInit) {
	        		return this.setParametrizacoes(parans);
	        	} else  {
	        		return parans;
	        	}
	    	} else {
	    		return 'Não retornaram dados de parametrização para essa filial.';
	    	}
	    }.bind(this));
	};
	
	this.setBlankLocalEstFields = function(widget){
		if(!widget.currentRow.hasOwnProperty('CDALMOXARIFE')){
			widget.currentRow.CDALMOXARIFE = ' ';
		}
		if(!widget.currentRow.hasOwnProperty('CDLOCALESTOQ')){
			widget.currentRow.CDLOCALESTOQ = ' ';
		}
		
		if(!widget.currentRow.hasOwnProperty('NRLOTEESTQ')){
			widget.currentRow.NRLOTEESTQ = ' ';
		}
		
		if(!widget.currentRow.hasOwnProperty('NRSUBLOTE')){
			widget.currentRow.NRSUBLOTE = ' ';
		} 

	};

	this.getPosicaoDeEstoquePorProduto = function(row) {
	    var filter = [
	    	{
	    		"name": "CDPRODUTO",
				"operator": "=",
				"value": row.CDPRODUTO
			},
			{
	    		"name": "CDFILIAL",
				"operator": "=",
				"value": row.CDFILIAL
			},
			{
	    		"name": "CDALMOXARIFE",
				"operator": "=",
				"value": row.CDALMOXARIFE
			},
			{
	    		"name": "CDLOCALESTOQ",
				"operator": "=",
				"value": row.CDLOCALESTOQ
			},
			{
	    		"name": "NRLOTEESTQ",
				"operator": "=",
				"value": row.NRLOTEESTQ
			},
			{
	    		"name": "NRSUBLOTE",
				"operator": "=",
				"value": row.NRSUBLOTE
			}
		];

	    return Est11000_EntradaEstoque_Repository.getPosicaoDeEstoquePorProduto(filter).then(function(success){
	    	return success.dataset.posestdia[0];
	    });
	};

	/**
	 *
	 *
	 */
	this.setQtLanctoEst = function(rowItem) {
    	rowItem.QTLANCTOEST = (rowItem.QTTOTLANCTO - rowItem.QTDEVOLESTOQ)*rowItem.VRFATOCONV;
    };

	/**
	 *
	 *
	 */
	this.save = function(lancamento,itens) {
	    // itens.forEach(function(item){
			// item.CDTIPORETI = lancamento.CDTIPORETI;
			// item.CDCENTCUST = lancamento.CDCENTCUST;
			// item.DTLANCMOVI = lancamento.DTLANCESTQ;

			//if(item.QTLANCTOEST > item.QTESTOQDIA){
 // código delphi para validar estoque negativo, conferir com fabricio se precisa, ao que parece o parametro que IDPERMESTNEG hoje nunca será 'S'
 // if (cdsParamFilialIDPERMESTNEG.Value = 'S') then begin
 //   cdsItLanctoEstCDARVPROD.EditMask := DBPict(ptProduto);
 //   if cdsParamFilialIDPERMVISPOSEST.Value <> 'N' then begin
 //     if MessageDlg(Format(msgPadrao.msg('Quant_Est'),[cdsItLanctoEstCDARVPROD.AsString, FormatFloat('#,##0.000 ',cdsVdPosEstDiaQTESTOQDIA.Value),cdsVdPosEstDiaSGUNIDADE.Value ])+ #13 + msgPadrao.msg('Confirma'),mtConfirmation,[mbYes,mbNo],0) = mrNo then begin
 //       dbgItemReti.SelectedIndex := IndiceCol(dbgItemReti,'QTLANCTOEST');
 //       Abort;
 //     end;
 //   end
 //   else begin
 //     if MessageDlg(msgPadrao.msg('Quant-Est')+msgPadrao.msg('Confirma'),mtConfirmation,[mbYes,mbNo],0) = mrNo then begin
 //       dbgItemReti.SelectedIndex := IndiceCol(dbgItemReti,'QTLANCTOEST');
 //       Abort;
 //     end;
 //   end;
 // end
			//}
			// Est11000_EntradaEstoque_Repository.save(lancamento,itens);
		// });

		itens.CDTIPORETI = lancamento.CDTIPORETI;
		itens.CDCENTCUST = lancamento.CDCENTCUST;
		itens.DTLANCMOVI = lancamento.DTLANCESTQ;

	};

	/**
	 *
	 *
	 */
	this.saveRetirada = function(row) {
		return Est11000_EntradaEstoque_Repository.saveRetirada(row);
	};

	/**
	 *
	 *
	 */
    this.setVrTotLancto = function(rowItem) {
    	rowItem.VRTOTLANCTO = rowItem.QTLANCTOEST * rowItem.VRUNILANCTO;
    };

	/**
	 * Essa função de tem como finalidade de setar as variavies desse controle com as
	 * clonuas que retornaram do selec das parametrizações da filial. Retorna a filial
	 * que foi passada para o select
	 *
	 * @param parans | um objeto com a row de parametrizações da filial
	 * @return array | array com o nome código da filial do select
	 */
	this.setParametrizacoes = function(parans) {
	    dtprocessa = parans.DTPROCESSA;
    	idctrlestq = parans.IDCTRLESTQ;
    	idutilalmox = parans.IDUTILALMOX;
    	idutillcestq = parans.IDUTILLCESTQ;
    	idpermestneg = parans.IDPERMESTNEG;
    	return [parans.CDFILIAL, parans.NMFILIAL];
	};

	/**
	 *
	 *
	 */
	this.validaItemRepetido=function(currentRow,data) {
		var validacao = true;
		data.forEach(function(row){
			if(currentRow.CDPRODUTO ===  row.CDPRODUTO && currentRow!== row)
				validacao = false;
		});
		return validacao;
	};

	/************************** Retorna parametrizações da filial **************************/

    /**
	 * Essa função tem como finalidae retornar se a filial selecionada no fritro utiliza
	 * controle estoque (true) ou não (false).
	 *
	 * @return bool | retorna true se utiliza e false se não utiliza.
	 */
	this.controlaEstq = function() {
	    if(idctrlestq === 'S') {
	        return true;
	    } else {
	        return false;
	    }
	};

    /**
     * Essa função tem como finalidade retornar a data de processamento da filial selecionada
     * no filtro. Se a filial não usar data de processamento é retornado a data atual, mas
     * essa validação é feita no backend pela query.
     *
     * @return string | data de processamento da filial
     */
    this.getDtprocessa = function() {
        return dtprocessa;
    };

	/**
	 * Essa função tem como finalidae retornar se a filial selecionada no fritro utiliza
	 * almoxarifado (true) ou não (false).
	 *
	 * @return bool | retorna true se utiliza e false se não utiliza.
	 */
	this.utilizaAlmoraifado = function() {
	    if(idutilalmox === 'S') {
	        return true;
	    } else {
	        return false;
	    }
	};

	/**
	 * Essa função tem como finalidae retornar se a filial selecionada no fritro utiliza
	 * localizacao (true) ou não (false).
	 *
	 * @return bool | retorna true se utiliza e false se não utiliza.
	 */
	this.utilizaLocalizacao = function() {
	    if(idutillcestq === 'S') {
	        return true;
	    } else {
	        return false;
	    }
	};
	

}

Configuration(function(ContextRegister) {
	ContextRegister.register('Est11000_EntradaEstoque_Service', Est11000_EntradaEstoque_Service);
});